tdub.frames
-----------

A module for handling dataframes.

.. currentmodule:: tdub.frames


Factory Function Summary
^^^^^^^^^^^^^^^^^^^^^^^^

.. autosummary::

   iterative_selection
   raw_dataframe

Helper Function Summary
^^^^^^^^^^^^^^^^^^^^^^^

.. autosummary::

   apply_weight
   apply_weight_campaign
   apply_weight_tptrw
   drop_avoid
   drop_cols
   drop_jet2
   satisfying_selection


Reference
^^^^^^^^^

.. autofunction:: iterative_selection
.. autofunction:: raw_dataframe
.. autofunction:: apply_weight
.. autofunction:: apply_weight_campaign
.. autofunction:: apply_weight_tptrw
.. autofunction:: drop_avoid
.. autofunction:: drop_cols
.. autofunction:: drop_jet2
.. autofunction:: satisfying_selection
